# Antur

![PyPI - Version](https://img.shields.io/pypi/v/antur?style=for-the-badge)
![PyPI - License](https://img.shields.io/pypi/l/antur?style=for-the-badge)
![GitHub Repo stars](https://img.shields.io/github/stars/jb3/antur?style=for-the-badge)

Antur is a Python TUI tool for browsing and debugging sitemap data.

> [!NOTE]
> This project is under development and may error/have bugs.

## Demo

![Demo](./resources/demo.gif)

## Installation

```bash
$ pip install antur
```

## Usage

```bash
$ antur
```

## License

MIT License. See [LICENSE](LICENSE) for more information.
